@@ -78,7 +78,7 @@ class HTML2FOConverter(object):
             raise IOError('%s does not exist' % csstoxslfo)
 
         cmd = '"%s"' % java + \
-              ' -Xms128m -Xmx128m -jar "%(csstoxslfo)s" "%(filename)s" -fo "%(fo_filename)s" country=%(country)s language=%(language)s' % vars()
+              ' -Duser.language=en -Xms128m -Xmx128m -jar "%(csstoxslfo)s" "%(filename)s" -fo "%(fo_filename)s" country=%(country)s language=%(language)s' % vars()
         status, output = runcmd(cmd)
         if status != 0:
             raise RuntimeError('Error executing: %s' % cmd)
